This tool infers spatial domain-like patterns from spatial gene expression data that are generated by multiplexed single molecule FISH or by other spatial profiling technologies

smfishHmrf-py is written in Python 3. It uses R/C++ to run the core HMRF inference (this is available in the link [smfishHmrf-R](https://bitbucket.org/qzhudfci/smfishhmrf-R)).
smfishHmrf-py is a Python package designed for interfacing with the smfishHMRF-r library and for visualizing the result.

**smfishHmrf-py is the package we recommend for running HMRF analysis**

We provide the installation of smfishHmrf-py in the below link:
http://spatial.rc.fas.harvard.edu/install.html

This includes both instructions to install the core R package, the smfishHmrf-py Python package (using pip), and some usage examples.
